@@ -48,7 +48,7 @@ OC.L10N.register(
     "before" : "před",
     "start" : "začátek",
     "end" : "konec",
-    "Editing reminders of uknown type not supported." : "Úprava připomínek neznámého typu není podporována. ",
+    "Editing reminders of unknown type not supported." : "Úprava upozornění neznámého typu není podporována.",
     "Week {number} of {year}" : "Týden {number} rok {year}",
     "Successfully imported" : "Úspěšně importován",
     "Partially imported, 1 failure" : "Částečně importován, 1 chyba",
@@ -68,17 +68,17 @@ OC.L10N.register(
     "starts" : "začíná",
     "ends" : "končí",
     "All day Event" : "Celodenní událost",
-    "Location" : "Umístění",
     "Delete" : "Smazat",
     "Cancel" : "Zrušit",
     "More ..." : "Více ...",
     "Create" : "Vytvořit",
     "Update" : "Aktualizovat",
     "Close" : "Zavřít",
+    "Location" : "Umístění",
     "Description" : "Popis",
     "Export" : "Exportovat",
     "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Kalendář v současné chvíli nemůže nabídnout podporu pro funkci \"asset pipeline\" (spojení a komprese css a js souborů).",
-    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Prosím, kontaktujte Vašeho administrátora a zeptejte se ho na zrušení funkce \"asset-pipeline.enabled\" v konfiguračním souboru.",
+    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Kontaktujte prosím svého administrátora a zeptejte se ho na zrušení funkce \"asset-pipeline.enabled\" v konfiguračním souboru.",
     "Day" : "Den",
     "Week" : "Týden",
     "Month" : "Měsíc",
@@ -87,6 +87,8 @@ OC.L10N.register(
     "More" : "Více",
     "Edit" : "Upravit",
     "CalDAV" : "CalDAV",
+    "Share with users or groups" : "Sdílet s uživateli nebo skupinami",
+    "can edit" : "lze upravovat",
     "group" : "skupina",
     "New Calendar" : "Nový kalendář",
     "Subscriptions" : "Odběry",
