@@ -10,6 +10,8 @@ OC.L10N.register(
     "Required" : "Krævet",
     "Optional" : "Valgfri",
     "Does not attend" : "Deltager ikke",
+    "You are in an unknown timezone ({tz}), falling back to UTC" : "Du er i en ukendt tidszone ({tz}), -sætter tiden til UTC",
+    "Please create a calendar first." : "Opret venligst en kalender først",
     "New event" : "Opret begivenhed",
     "Attendees" : "Deltagere",
     "Reminders" : "Påmindindelser",
@@ -43,6 +45,10 @@ OC.L10N.register(
     "hours" : "timer",
     "days" : "dage",
     "week" : "uge",
+    "before" : "før",
+    "start" : "start",
+    "end" : "slut",
+    "Editing reminders of unknown type not supported." : "Redigeringspåmindelser, af ukendt type, er ikke understøttet.",
     "Week {number} of {year}" : "Uge {number} i {year}",
     "Successfully imported" : "Importeret succesfuldt",
     "Partially imported, 1 failure" : "Delvist importeret, 1 fejl",
@@ -56,20 +62,22 @@ OC.L10N.register(
     "{type} {time} after the event ends" : "{type} {time} efter begivenheden slutter",
     "{type} at the event's start" : "{type} ved begivenhedens begyndelse",
     "{type} at the event's end" : "{type} ved begivenhedens slutning",
+    "{type} at {time}" : "{type} på {time}",
     "{calendar} shared by {owner}" : "{calendar} delt af {owner}",
     "Title of the Event" : "Titel på begivenheden",
     "starts" : "starter",
     "ends" : "slutter",
     "All day Event" : "Heldagsbegivenhed",
-    "Location" : "Placering",
     "Delete" : "Slet",
     "Cancel" : "Annullér",
     "More ..." : "Mere...",
     "Create" : "Ny",
     "Update" : "Opdatér",
     "Close" : "Luk",
+    "Location" : "Placering",
     "Description" : "Beskrivelse",
     "Export" : "Eksportér",
+    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "På grund af en \"upstream bug\", er kalenderen, i øjeblikket, ikke i stand til at understøtte funktionen \"asset pipeline\".",
     "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Kontakt venligst din administrator og bed om at \"asset-pipeline.enabled\" bliver slået fra.",
     "Day" : "Dag",
     "Week" : "Uge",
@@ -78,6 +86,9 @@ OC.L10N.register(
     "Share Calendar" : "Del kalender",
     "More" : "Mere",
     "Edit" : "Redigér",
+    "CalDAV" : "CalDAV",
+    "Share with users or groups" : "Del med brugere eller grupper",
+    "can edit" : "kan redigere",
     "group" : "gruppe",
     "New Calendar" : "Ny kalender",
     "Subscriptions" : "Abonnementer",
@@ -97,6 +108,12 @@ OC.L10N.register(
     "Please add your email address in the personal settings in order to add attendees." : "Tilføj din e-mailadresse under Personlige indstillinger for at kunne invitere deltagere.",
     "from" : "fra",
     "to" : "til",
+    "This event's repeating rule is not supported yet." : "Denne begivenheds gentagelsesregel understøttes ikke endnu.",
+    "Support for advanced rules will be added with subsequent updates." : "Understøttelse af avancerede regler, vil blive tilføjet ved senere opdateringer.",
+    "Reset repeating rule" : "Nulstil gentagelsesregel",
+    "Repeat every ..." : "Gentag hver ...",
+    "end repeat ..." : "stop gentagelse ...",
+    "times" : "gange",
     "Import Calendars" : "Importer kalenderere",
     "Import canceled" : "Importering annulleret",
     "Analyzing calendar" : "Analyserer kalender",
