@@ -48,7 +48,7 @@ OC.L10N.register(
     "before" : "before",
     "start" : "start",
     "end" : "end",
-    "Editing reminders of uknown type not supported." : "Editing reminders of unknown type not supported.",
+    "Editing reminders of unknown type not supported." : "Editing reminders of unknown type not supported.",
     "Week {number} of {year}" : "Week {number} of {year}",
     "Successfully imported" : "Successfully imported",
     "Partially imported, 1 failure" : "Partially imported, 1 failure",
@@ -68,13 +68,13 @@ OC.L10N.register(
     "starts" : "starts",
     "ends" : "ends",
     "All day Event" : "All day Event",
-    "Location" : "Location",
     "Delete" : "Delete",
     "Cancel" : "Cancel",
     "More ..." : "More ...",
     "Create" : "Create",
     "Update" : "Update",
     "Close" : "Close",
+    "Location" : "Location",
     "Description" : "Description",
     "Export" : "Export",
     "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature.",
@@ -87,6 +87,8 @@ OC.L10N.register(
     "More" : "More",
     "Edit" : "Edit",
     "CalDAV" : "CalDAV",
+    "Share with users or groups" : "Share with users or groups",
+    "can edit" : "can edit",
     "group" : "group",
     "New Calendar" : "New Calendar",
     "Subscriptions" : "Subscriptions",
