@@ -48,7 +48,7 @@ OC.L10N.register(
     "before" : "antes",
     "start" : "comienzo",
     "end" : "fin",
-    "Editing reminders of uknown type not supported." : "Los recordatorios de edición de tipo desconocido no están soportados.",
+    "Editing reminders of unknown type not supported." : "No esta soportado el editar recordatorios de tipo desconocido.",
     "Week {number} of {year}" : "Semana {number} de {year}",
     "Successfully imported" : "Importado exitosamente",
     "Partially imported, 1 failure" : "Parcialmente importardo, 1 error",
@@ -68,13 +68,13 @@ OC.L10N.register(
     "starts" : "comienza",
     "ends" : "finaliza",
     "All day Event" : "Todo el día",
-    "Location" : "Ubicación",
     "Delete" : "Eliminar",
     "Cancel" : "Cancelar",
     "More ..." : "Más...",
     "Create" : "Crear",
     "Update" : "Actualizar",
     "Close" : "Cerrar",
+    "Location" : "Ubicación",
     "Description" : "Descripción",
     "Export" : "Exportar",
     "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Debido a un bug de upstream, el calendario no soporta la funcionalidad de asset pipeline",
@@ -87,6 +87,8 @@ OC.L10N.register(
     "More" : "Más",
     "Edit" : "Editar",
     "CalDAV" : "CalDAV",
+    "Share with users or groups" : "Compartir con usuarios o grupos",
+    "can edit" : "puede editar",
     "group" : "grupo",
     "New Calendar" : "Nuevo calendario",
     "Subscriptions" : "Suscripciones",
@@ -103,7 +105,7 @@ OC.L10N.register(
     "times every" : "veces cada",
     "Add" : "Añadir",
     "E-Mail address of attendee" : "Correo electrónico del asistente",
-    "Please add your email address in the personal settings in order to add attendees." : "Por favor indique su e-mail en los ajustes de su cuenta para agregar asistentes",
+    "Please add your email address in the personal settings in order to add attendees." : "Por favor indique su correo electrónico en la configuración de su cuenta para agregar asistentes",
     "from" : "desde",
     "to" : "para",
     "This event's repeating rule is not supported yet." : "Esta regla de repetición de eventos aún no está soportada.",
