@@ -48,7 +48,7 @@ OC.L10N.register(
     "before" : "avant",
     "start" : "début",
     "end" : "fin",
-    "Editing reminders of uknown type not supported." : "L'édition de rappels de type inconnu n'est pas supportée.",
+    "Editing reminders of unknown type not supported." : "L'édition de rappels de type inconnu n'est pas supportée.",
     "Week {number} of {year}" : "Semaine {number} de {year}",
     "Successfully imported" : "Importé avec succès",
     "Partially imported, 1 failure" : "Partiellement importé, 1 échec",
@@ -68,13 +68,13 @@ OC.L10N.register(
     "starts" : "démarre",
     "ends" : "termine",
     "All day Event" : "Journée entière",
-    "Location" : "Emplacement",
     "Delete" : "Supprimer",
     "Cancel" : "Annuler",
     "More ..." : "Plus…",
     "Create" : "Créer",
     "Update" : "Mettre à jour",
     "Close" : "Fermer",
+    "Location" : "Emplacement",
     "Description" : "Description",
     "Export" : "Exporter",
     "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "A cause d'un bug en amont, le calendrier ne peut actuellement pas prendre en charge la fonction de pipeline d'actifs.",
@@ -82,11 +82,13 @@ OC.L10N.register(
     "Day" : "Jour",
     "Week" : "Semaine",
     "Month" : "Mois",
-    "Today" : "Aujourd'hui",
+    "Today" : "Auj.",
     "Share Calendar" : "Partager l'agenda",
     "More" : "Plus",
     "Edit" : "Éditer",
     "CalDAV" : "CalDAV",
+    "Share with users or groups" : "Partager avec des utilisateurs ou des groupes",
+    "can edit" : "peut modifier",
     "group" : "groupe",
     "New Calendar" : "Nouvel agenda",
     "Subscriptions" : "Abonnements",
