@@ -10,6 +10,8 @@ OC.L10N.register(
     "Required" : "þetta þarf",
     "Optional" : "Valkvætt",
     "Does not attend" : "Mætir ekki",
+    "You are in an unknown timezone ({tz}), falling back to UTC" : "Þú ert á óþekktu tímabelti ({tz}), fell aftur á UTC-tíma",
+    "Please create a calendar first." : "Búðu fyrst til dagatal.",
     "New event" : "Nýr atburður",
     "Attendees" : "Þáttakendur",
     "Reminders" : "Áminningar",
@@ -46,7 +48,7 @@ OC.L10N.register(
     "before" : "fyrir",
     "start" : "upphaf",
     "end" : "endir",
-    "Editing reminders of uknown type not supported." : "Breytingar á áminningum með óþekktu sniði er ekki stutt.",
+    "Editing reminders of unknown type not supported." : "Breytingar á áminningum með óþekktu sniði er ekki stutt.",
     "Week {number} of {year}" : "Vika {number},{year}",
     "Successfully imported" : "Innflutningur tókst",
     "Partially imported, 1 failure" : "Flutt inn að hluta, 1 villa",
@@ -66,13 +68,13 @@ OC.L10N.register(
     "starts" : "byrjar",
     "ends" : "endar",
     "All day Event" : "Heilsdagsviðburður",
-    "Location" : "Staðsetning",
     "Delete" : "Eyða",
     "Cancel" : "Hætta við",
     "More ..." : "Meira...",
     "Create" : "Búa til",
     "Update" : "Uppfæra",
     "Close" : "Loka",
+    "Location" : "Staðsetning",
     "Description" : "Lýsing",
     "Export" : "Flytja út",
     "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Vegna villu í frumkóða, verður dagatalið ekki nothæft með stuðningi við pípaða vinnslu tilfanga.",
@@ -84,6 +86,9 @@ OC.L10N.register(
     "Share Calendar" : "Deila dagatali",
     "More" : "Meira",
     "Edit" : "Breyta",
+    "CalDAV" : "CalDAV",
+    "Share with users or groups" : "Deila með notendum eða hópum",
+    "can edit" : "getur breytt",
     "group" : "hópur",
     "New Calendar" : "Nýtt dagatal",
     "Subscriptions" : "Áskriftir",
