@@ -48,7 +48,7 @@ OC.L10N.register(
     "before" : "prima",
     "start" : "inizia",
     "end" : "finisce",
-    "Editing reminders of uknown type not supported." : "La modifica dei promemoria di tipo sconosciuto non è supportata.",
+    "Editing reminders of unknown type not supported." : "La modifica di promemoria di tipo sconosciuto non è supportata.",
     "Week {number} of {year}" : "Settimana {number} del {year}",
     "Successfully imported" : "Importato correttamente",
     "Partially imported, 1 failure" : "Importato parzialmente, 1 problema",
@@ -68,13 +68,13 @@ OC.L10N.register(
     "starts" : "inizia",
     "ends" : "finisce",
     "All day Event" : "Evento di un giorno intero",
-    "Location" : "Posizione",
     "Delete" : "Elimina",
     "Cancel" : "Annulla",
     "More ..." : "Altro...",
     "Create" : "Crea",
     "Update" : "Aggiorna",
     "Close" : "Chiudi",
+    "Location" : "Posizione",
     "Description" : "Descrizione",
     "Export" : "Esporta",
     "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "A causa di un bug a monte, il calendario non è attualmente in grado di fornire supporto per la funzionalità di asset pipeline.",
@@ -87,6 +87,8 @@ OC.L10N.register(
     "More" : "Altro",
     "Edit" : "Modifica",
     "CalDAV" : "CalDAV",
+    "Share with users or groups" : "Condividi con utenti o gruppi",
+    "can edit" : "può modificare",
     "group" : "gruppo",
     "New Calendar" : "Nuovo calendario",
     "Subscriptions" : "Sottoscrizioni",
