@@ -10,6 +10,8 @@ OC.L10N.register(
     "Required" : "Påkrevet",
     "Optional" : "Valgfri",
     "Does not attend" : "Deltar ikke",
+    "You are in an unknown timezone ({tz}), falling back to UTC" : "Du er i en ukjent tidssone ({tz}), faller tilbake til UTC",
+    "Please create a calendar first." : "Vennligst opprett en kalender først",
     "New event" : "Ny hendelse",
     "Attendees" : "Deltakere",
     "Reminders" : "Varsler",
@@ -43,6 +45,10 @@ OC.L10N.register(
     "hours" : "timer",
     "days" : "dager",
     "week" : "uke",
+    "before" : "før",
+    "start" : "start",
+    "end" : "slutt",
+    "Editing reminders of unknown type not supported." : "Redigering av varsler av ukjent type støttes ikke.",
     "Week {number} of {year}" : "Uke {number} {year}",
     "Successfully imported" : "Vellykket importert",
     "Partially imported, 1 failure" : "Delvis importert, 1 feil",
@@ -62,13 +68,13 @@ OC.L10N.register(
     "starts" : "starter",
     "ends" : "slutter",
     "All day Event" : "Heldagshendelse",
-    "Location" : "Sted",
     "Delete" : "Slett",
     "Cancel" : "Avbryt",
     "More ..." : "Mer ...",
     "Create" : "Opprett",
     "Update" : "Oppdater",
     "Close" : "Lukk",
+    "Location" : "Sted",
     "Description" : "Beskrivelse",
     "Export" : "Eksporter",
     "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Pga. en feil oppstrøms, støtter kalenderen for tiden ikke \"asset pipeline\".",
@@ -80,6 +86,9 @@ OC.L10N.register(
     "Share Calendar" : "Del kalender",
     "More" : "Mer",
     "Edit" : "Endre",
+    "CalDAV" : "CalDAV",
+    "Share with users or groups" : "Del med brukere eller grupper",
+    "can edit" : "kan endre",
     "group" : "gruppe",
     "New Calendar" : "Ny kalender",
     "Subscriptions" : "Abonnement",
