@@ -48,7 +48,7 @@ OC.L10N.register(
     "before" : "voor",
     "start" : "start",
     "end" : "einde",
-    "Editing reminders of uknown type not supported." : "Bijwerken van herinneringen van een onbekend type is niet ondersteund.",
+    "Editing reminders of unknown type not supported." : "Bewerken van herinneringen van onbekende types wordt niet ondersteund.",
     "Week {number} of {year}" : "Week {number} van {year}",
     "Successfully imported" : "Succesvol geïmporteerd",
     "Partially imported, 1 failure" : "Gedeeltelijk geïmporteerd, 1 fout",
@@ -68,13 +68,13 @@ OC.L10N.register(
     "starts" : "begint",
     "ends" : "eindigt",
     "All day Event" : "Hele dag",
-    "Location" : "Locatie",
     "Delete" : "Verwijderen",
     "Cancel" : "Annuleren",
     "More ..." : "Meer...",
     "Create" : "Aanmaken",
     "Update" : "Bijwerken",
     "Close" : "Sluiten",
+    "Location" : "Locatie",
     "Description" : "Beschrijving",
     "Export" : "Exporteer",
     "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Wegens een upstream bug kan de kalender nu de asset pipeline mogelijkheid niet ondersteunen.",
@@ -87,6 +87,8 @@ OC.L10N.register(
     "More" : "Meer",
     "Edit" : "Bewerk",
     "CalDAV" : "CalDAV",
+    "Share with users or groups" : "Delen met gebruikers of groepen",
+    "can edit" : "kan wijzigen",
     "group" : "groep",
     "New Calendar" : "Nieuwe agenda",
     "Subscriptions" : "Abonnementen",
