@@ -39,6 +39,7 @@ OC.L10N.register(
     "Custom" : "Dowolnie",
     "Audio" : "Dźwięk",
     "E Mail" : "e-mail",
+    "Pop up" : "Powiadomienie",
     "sec" : "sek",
     "min" : "min",
     "hours" : "godzin",
@@ -47,7 +48,7 @@ OC.L10N.register(
     "before" : "przed",
     "start" : "rozpocznij",
     "end" : "zakończ",
-    "Editing reminders of uknown type not supported." : "Edycja przypomnień nieznanego typu nie jest wspierana.",
+    "Editing reminders of unknown type not supported." : "Edycja przypomnień nieznanego typu nie jest wspierana.",
     "Week {number} of {year}" : "{number}. tydzień {year}",
     "Successfully imported" : "Import zakończył się pomyślnie",
     "Partially imported, 1 failure" : "Import wykonany częściowo, 1 błąd",
@@ -67,15 +68,16 @@ OC.L10N.register(
     "starts" : "rozpoczyna się",
     "ends" : "kończy się",
     "All day Event" : "Wydarzenie całodniowe",
-    "Location" : "Lokalizacja",
     "Delete" : "Usuń",
     "Cancel" : "Anuluj",
     "More ..." : "Więcej...",
     "Create" : "Utwórz",
     "Update" : "Aktualizuj",
     "Close" : "Zamknij",
+    "Location" : "Lokalizacja",
     "Description" : "Opis",
     "Export" : "Eksportuj",
+    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Z powodu błędu w zewnętrznej bibliotece, kalendarz nie wspiera funkcji \"asset pipeline\".",
     "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Skontaktuj się z administratorem i poproś o wyłączenie opcji \"asset-pipeline.enabled\"  w konfiguracji.",
     "Day" : "Dzień",
     "Week" : "Tydzień",
@@ -84,6 +86,9 @@ OC.L10N.register(
     "Share Calendar" : "Współdziel kalendarz",
     "More" : "Więcej",
     "Edit" : "Edytuj",
+    "CalDAV" : "CalDAV",
+    "Share with users or groups" : "Współdziel z grupami bądź użytkownikami",
+    "can edit" : "może edytować",
     "group" : "grupa",
     "New Calendar" : "Nowy kalendarz",
     "Subscriptions" : "Subskrypcje",
@@ -97,14 +102,18 @@ OC.L10N.register(
     "Relative" : "Pokrewny",
     "Absolute" : "Całkowity",
     "Repeat" : "Powtarzaj",
+    "times every" : "razy w każdy",
     "Add" : "Dodaj",
     "E-Mail address of attendee" : "Adres e-mail uczestnika",
     "Please add your email address in the personal settings in order to add attendees." : "Aby móc dodać uczestników, proszę ustawić adres e-mail w ustawieniach konta.",
     "from" : "z",
     "to" : "do",
+    "This event's repeating rule is not supported yet." : "Ta reguła powtarzania wydarzenia nie jest jeszcze wspierana.",
+    "Support for advanced rules will be added with subsequent updates." : "Wsparcie dla zaawansowanych zasad będzie wprowadzane sukcesywnie wraz z kolejnymi aktualizacjami.",
     "Reset repeating rule" : "Zresetuj powtarzającą się zasadę",
     "Repeat every ..." : "Powtarzaj każdą...",
     "end repeat ..." : "zakończ powtarzanie ...",
+    "times" : "razy",
     "Import Calendars" : "Importuj Kalendarze",
     "Import canceled" : "Import anulowany",
     "Analyzing calendar" : "Analiza kalendarza",
