@@ -48,7 +48,7 @@ OC.L10N.register(
     "before" : "antes",
     "start" : "início",
     "end" : "fim",
-    "Editing reminders of uknown type not supported." : "Não é possível editar lembretes de tipos desconhecidos.",
+    "Editing reminders of unknown type not supported." : "Lembretes de edição de tipos desconhecidos não são suportados.",
     "Week {number} of {year}" : "Semana {number} de {year}",
     "Successfully imported" : "Importada com sucesso",
     "Partially imported, 1 failure" : "Parcialmente importada, 1 falha",
@@ -68,13 +68,13 @@ OC.L10N.register(
     "starts" : "Inícios",
     "ends" : "Finais",
     "All day Event" : "Evento todo o dia",
-    "Location" : "Localização",
     "Delete" : "Excluir",
     "Cancel" : "Cancelar",
     "More ..." : "Mais ...",
     "Create" : "Criar",
     "Update" : "Atualizar",
     "Close" : "Fechar",
+    "Location" : "Localização",
     "Description" : "Descrição",
     "Export" : "Exportar",
     "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Devido a um bug a montante, o calendário não é atualmente capaz de fornecer suporte para o recurso de pipeline ativo.",
@@ -87,6 +87,8 @@ OC.L10N.register(
     "More" : "Mais",
     "Edit" : "Editar",
     "CalDAV" : "CalDAV",
+    "Share with users or groups" : "Compartilhar com usuários ou grupos",
+    "can edit" : "pode editar",
     "group" : "grupo",
     "New Calendar" : "Novo Calendário",
     "Subscriptions" : "Inscrições",
