@@ -5,13 +5,13 @@ OC.L10N.register(
     "Individual" : "Individual",
     "Group" : "Grupo",
     "Resource" : "Recurso",
-    "Room" : "Quarto",
+    "Room" : "Sala",
     "Unknown" : "Desconhecido",
     "Required" : "Obrigatório",
     "Optional" : "Opcional",
     "Does not attend" : "Não comparecerá",
-    "You are in an unknown timezone ({tz}), falling back to UTC" : "Está numa zona horário desconhecida ({tz}), a repor para UTC",
-    "Please create a calendar first." : "Por favor crie um calendário primeiro.",
+    "You are in an unknown timezone ({tz}), falling back to UTC" : "Está numa zona horária desconhecida ({tz}), a repor para UTC",
+    "Please create a calendar first." : "Por favor, crie primeiro um calendário.",
     "New event" : "Novo evento",
     "Attendees" : "Participantes",
     "Reminders" : "Lembretes",
@@ -38,18 +38,18 @@ OC.L10N.register(
     "2 hours before" : "2 horas antes",
     "Custom" : "Personalizado",
     "Audio" : "Áudio",
-    "E Mail" : "E-mail",
+    "E Mail" : "Correio Eletrónico",
     "Pop up" : "Janela de Aviso",
     "sec" : "seg.",
-    "min" : "mínimo",
+    "min" : "min",
     "hours" : "horas",
     "days" : "dias",
     "week" : "semana",
     "before" : "antes",
-    "start" : "Inicio",
+    "start" : "inicio",
     "end" : "fim",
-    "Editing reminders of uknown type not supported." : "Não é suportada a edição de lembretes de tipo desconhecido.",
-    "Week {number} of {year}" : "Semana {number} de {year}",
+    "Editing reminders of unknown type not supported." : "Não é suportada a edição de lembretes do tipo desconhecido.",
+    "Week {number} of {year}" : "Semana {number} do {year}",
     "Successfully imported" : "Importado com sucesso",
     "Partially imported, 1 failure" : "Parcialmente importado, 1 erro",
     "Partially imported, {n} failures" : "Parcialmente importado, {n} erros",
@@ -60,7 +60,7 @@ OC.L10N.register(
     "{type} {time} before the event ends" : "{type} {time} antes do evento terminar",
     "{type} {time} after the event starts" : "{type} {time} depois do evento começar",
     "{type} {time} after the event ends" : "{type} {time} depois do evento terminar",
-    "{type} at the event's start" : "{type} no começo do evento",
+    "{type} at the event's start" : "{type} no início do evento",
     "{type} at the event's end" : "{type} no final do evento",
     "{type} at {time}" : "{type} às {time}",
     "{calendar} shared by {owner}" : "{calendar} partilhado por {owner}",
@@ -68,13 +68,13 @@ OC.L10N.register(
     "starts" : "começa",
     "ends" : "termina",
     "All day Event" : "Evento todo o dia",
-    "Location" : "Localização:",
     "Delete" : "Eliminar",
     "Cancel" : "Cancelar",
     "More ..." : "Mais...",
     "Create" : "Criar",
     "Update" : "Atualizar",
     "Close" : "Fechar",
+    "Location" : "Localização:",
     "Description" : "Descrição",
     "Export" : "Exportar",
     "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Devido a um erro próximo da fonte, o calendário atualmente não consegue dar suporte para a função de transporte do recurso.",
@@ -83,10 +83,12 @@ OC.L10N.register(
     "Week" : "Semana",
     "Month" : "Mês",
     "Today" : "Hoje",
-    "Share Calendar" : "Partilhar Calendário",
+    "Share Calendar" : "Comartilhar Calendário",
     "More" : "Mais",
     "Edit" : "Editar",
     "CalDAV" : "CalDAV",
+    "Share with users or groups" : "Partilhe com os utilizadores ou grupos",
+    "can edit" : "pode editar",
     "group" : "grupo",
     "New Calendar" : "Novo Calendário",
     "Subscriptions" : "Subscrições",
@@ -107,7 +109,7 @@ OC.L10N.register(
     "from" : "de",
     "to" : "para",
     "This event's repeating rule is not supported yet." : "A regra de repetição deste evento ainda não é suportada.",
-    "Support for advanced rules will be added with subsequent updates." : "Suporte para regras avançadas será adicionado nas atualizações subsequentes.",
+    "Support for advanced rules will be added with subsequent updates." : "O suporte para as regras avançadas será adicionado nas atualizações subsequentes.",
     "Reset repeating rule" : "Reiniciar a regra de repetição",
     "Repeat every ..." : "Repetir a cada... ",
     "end repeat ..." : "terminar repetição...",
@@ -122,6 +124,6 @@ OC.L10N.register(
     "Import calendar" : "Importar calendário",
     "No Calendars selected for import" : "Sem Calendários selecionados para importar",
     "Primary CalDAV address" : "Endereço principal CalDAV",
-    "iOS/OS X CalDAV address" : "iOS/OS X endereço CalDAV"
+    "iOS/OS X CalDAV address" : "Endereço CalDAV de iOS/OS X"
 },
 "nplurals=2; plural=(n != 1);");
