@@ -48,7 +48,7 @@ OC.L10N.register(
     "before" : "прежде",
     "start" : "начало",
     "end" : "конец",
-    "Editing reminders of uknown type not supported." : "Редактирование напоминания неизвестного типа не поддерживается.",
+    "Editing reminders of unknown type not supported." : "Редактирование напоминаний неизвестного типа не поддерживается.",
     "Week {number} of {year}" : "{number} неделя {year} года",
     "Successfully imported" : "Успешно импортировано",
     "Partially imported, 1 failure" : "Частично импортировано, 1 ошибка",
@@ -68,13 +68,13 @@ OC.L10N.register(
     "starts" : "начинается",
     "ends" : "заканчивается",
     "All day Event" : "Событие на весь день",
-    "Location" : "Местоположение",
     "Delete" : "Удалить",
     "Cancel" : "Отмена",
     "More ..." : "Больше ...",
     "Create" : "Создать",
     "Update" : "Обновить",
     "Close" : "Закрыть",
+    "Location" : "Местоположение",
     "Description" : "Описание",
     "Export" : "Экспорт",
     "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Из-за предшествующей ошибки, календарь в настоящее время не в состоянии обеспечить поддержку функции файлопровода.",
@@ -87,6 +87,8 @@ OC.L10N.register(
     "More" : "Больше",
     "Edit" : "Редактировать",
     "CalDAV" : "CalDAV",
+    "Share with users or groups" : "Общий доступ с пользователями или группами",
+    "can edit" : "можно редактировать",
     "group" : "группа",
     "New Calendar" : "Новый Календарь",
     "Subscriptions" : "Подписки",
