@@ -48,7 +48,7 @@ OC.L10N.register(
     "before" : "pred",
     "start" : "začetek",
     "end" : "konec",
-    "Editing reminders of uknown type not supported." : "Urejanje opomnikov neznane vrste ni podprto.",
+    "Editing reminders of unknown type not supported." : "Urejanje opomnikov neznane vrste ni podprto.",
     "Week {number} of {year}" : "{number}. teden leta {year}",
     "Successfully imported" : "Uvoz uspešno končan",
     "Partially imported, 1 failure" : "Delno uvoženo, zaznana je 1 napaka",
@@ -68,13 +68,13 @@ OC.L10N.register(
     "starts" : "začetek",
     "ends" : "konec",
     "All day Event" : "Celodnevni dogodek",
-    "Location" : "Mesto",
     "Delete" : "Izbriši",
     "Cancel" : "Prekliči",
     "More ..." : "Več ...",
     "Create" : "Ustvari",
     "Update" : "Posodobi",
     "Close" : "Zapri",
+    "Location" : "Mesto",
     "Description" : "Opis",
     "Export" : "Izvozi",
     "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Zaradi znanega hrošča v koledarju trenutno ni mogoča podpora zmožnosti skrčenja kode javascript in CSS.",
@@ -87,6 +87,8 @@ OC.L10N.register(
     "More" : "Več",
     "Edit" : "Uredi",
     "CalDAV" : "CalDAV",
+    "Share with users or groups" : "Souporaba z uporabniki ali skupinami",
+    "can edit" : "lahko ureja",
     "group" : "skupina",
     "New Calendar" : "Nov koledar",
     "Subscriptions" : "Naročila",
