@@ -48,7 +48,7 @@ OC.L10N.register(
     "before" : "përpara",
     "start" : "fillim",
     "end" : "mbarim",
-    "Editing reminders of uknown type not supported." : "Nuk mbulohet përpunimi i kujtuesve të një lloji të panjohur.",
+    "Editing reminders of unknown type not supported." : "Nuk mbulohet përpunimi i kujtuesve të një lloji të panjohur.",
     "Week {number} of {year}" : "Java e {number} e {year}",
     "Successfully imported" : "U importua me sukses",
     "Partially imported, 1 failure" : "Importuar pjesërisht, 1 dështim",
@@ -68,13 +68,13 @@ OC.L10N.register(
     "starts" : "fillon",
     "ends" : "mbaron",
     "All day Event" : "Veprimtari Gjithëditore",
-    "Location" : "Vendndodhje",
     "Delete" : "Fshije",
     "Cancel" : "Anuloje",
     "More ..." : "Më tepër …",
     "Create" : "Krijoje",
     "Update" : "Përditësoje",
     "Close" : "Mbylle",
+    "Location" : "Vendndodhje",
     "Description" : "Përshkrim",
     "Export" : "Eksportoji",
     "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Për shkak të një të mete në degën kryesore, kalendari, hëpërhë, s’është në gjendje të ofrojë mbulim të veçorinë \"asset pipeline\".",
@@ -87,6 +87,8 @@ OC.L10N.register(
     "More" : "Më tepër",
     "Edit" : "Përpunoni",
     "CalDAV" : "CalDAV",
+    "Share with users or groups" : "Ndajeni me përdorues ose grupe",
+    "can edit" : "mund të përpunojnë",
     "group" : "grup",
     "New Calendar" : "Kalendar i ri",
     "Subscriptions" : "Pajtime",
