@@ -48,7 +48,7 @@ OC.L10N.register(
     "before" : "före",
     "start" : "start",
     "end" : "slut",
-    "Editing reminders of uknown type not supported." : "Att redigera påminnelser för okända typer stödjs inte.",
+    "Editing reminders of unknown type not supported." : "Att redigera påminnelser för okända typer stöds inte.",
     "Week {number} of {year}" : "Vecka {number} av {year}",
     "Successfully imported" : "Lyckad importering",
     "Partially imported, 1 failure" : "Delvis importerad, 1 fel",
@@ -68,13 +68,13 @@ OC.L10N.register(
     "starts" : "börjar",
     "ends" : "slutar",
     "All day Event" : "Heldags evenemang",
-    "Location" : "Plats",
     "Delete" : "Ta bort",
     "Cancel" : "Avbryt",
     "More ..." : "Mer ...",
     "Create" : "Skapa",
     "Update" : "Uppdatera",
     "Close" : "Stäng",
+    "Location" : "Plats",
     "Description" : "Beskrivning",
     "Export" : "Exportera",
     "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "På grund utav en bug uppströms, så kan inte calendar ge någon support för asset pipeline funktionen.",
@@ -87,6 +87,8 @@ OC.L10N.register(
     "More" : "Mer",
     "Edit" : "Ändra",
     "CalDAV" : "CalDAV",
+    "Share with users or groups" : "Dela med användare eller grupper",
+    "can edit" : "kan redigera",
     "group" : "Grupp",
     "New Calendar" : "Ny kalender",
     "Subscriptions" : "Prenumerationer",
@@ -106,7 +108,7 @@ OC.L10N.register(
     "Please add your email address in the personal settings in order to add attendees." : "Vänligen lägg till din e-mailadress i personliga inställningar för att kunna lägga till deltagare",
     "from" : "från",
     "to" : "till",
-    "This event's repeating rule is not supported yet." : "Detta events repeteringsregel stödjs inte ännu",
+    "This event's repeating rule is not supported yet." : "Detta events repeteringsregel stöds inte ännu",
     "Support for advanced rules will be added with subsequent updates." : "Support för advancerade regler kommer läggas till i senare uppdateringar.",
     "Reset repeating rule" : "Radera repeteringsregeln",
     "Repeat every ..." : "Repetera varje ...",
