@@ -48,7 +48,7 @@ OC.L10N.register(
     "before" : "ก่อน",
     "start" : "เริ่ม",
     "end" : "จบ",
-    "Editing reminders of uknown type not supported." : "การแก้ไขการแจ้งเตือนประเภทที่ไม่รู้จักไม่ได้รับการสนับสนุน",
+    "Editing reminders of unknown type not supported." : "แจ้งเตือนการแก้ไขที่ไม่รู้จัก ไม่ได้รับการสนับสนุน",
     "Week {number} of {year}" : "สัปดาห์ที่ {number} ของปี {year}",
     "Successfully imported" : "นำเข้าสำเร็จ",
     "Partially imported, 1 failure" : "นำเข้าได้แค่บางส่วน ล้มเหลวไปแล้ว 1 ",
@@ -68,13 +68,13 @@ OC.L10N.register(
     "starts" : "เริ่ม",
     "ends" : "จบ",
     "All day Event" : "เหตุการณ์ตลอดทั้งวัน",
-    "Location" : "ตำแหน่งที่อยู่",
     "Delete" : "ลบ",
     "Cancel" : "ยกเลิก",
     "More ..." : "เพิ่มเติม ...",
     "Create" : "สร้าง",
     "Update" : "อัพเดท",
     "Close" : "ปิด",
+    "Location" : "ตำแหน่งที่อยู่",
     "Description" : "รายละเอียด",
     "Export" : "ส่งออก",
     "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "เนื่องจากข้อผิดพลาดจากต้นทาง ปัจจุบันปฏิทินยังไม่ให้การสนับสนุนสำหรับคุณลักษณะ asset pipeline",
@@ -87,6 +87,8 @@ OC.L10N.register(
     "More" : "เพิ่มเติม",
     "Edit" : "แก้ไข",
     "CalDAV" : "CalDAV",
+    "Share with users or groups" : "แชร์กับผู้ใช้หรือกลุ่ม",
+    "can edit" : "สามารถแก้ไข",
     "group" : "กลุ่มผู้ใช้งาน",
     "New Calendar" : "สร้างปฏิทินใหม่",
     "Subscriptions" : "สมัครสมาชิก",
@@ -107,7 +109,7 @@ OC.L10N.register(
     "from" : "จาก",
     "to" : "ถึง",
     "This event's repeating rule is not supported yet." : "กฎการทำซ้ำของเหตุการณ์นี้ยังไม่ได้รับการสนับสนุน",
-    "Support for advanced rules will be added with subsequent updates." : "การสนับสนุนสำหรับกฎขั้นสูงจะถูกเพิ่มในภายหลังที่มีการปรับปรุง",
+    "Support for advanced rules will be added with subsequent updates." : "การสนับสนุนสำหรับกฎขั้นสูงจะถูกเพิ่มในภายหลังที่มีการอัพเดท",
     "Reset repeating rule" : "รีเซ็ตกฎการทำซ้ำ",
     "Repeat every ..." : "ทำซ้ำตลอด ...",
     "end repeat ..." : "ยกเลิกการทำซ้ำ ...",
