@@ -10,6 +10,7 @@ OC.L10N.register(
     "Required" : "必填",
     "Optional" : "选填",
     "Does not attend" : "不参加",
+    "You are in an unknown timezone ({tz}), falling back to UTC" : "您处于未知时区({tz}),请调整回UTC时间",
     "Please create a calendar first." : "请先创建一个新的日历。",
     "New event" : "新事件",
     "Attendees" : "参加者",
@@ -27,6 +28,7 @@ OC.L10N.register(
     "Every month" : "每月",
     "Every year" : "每年",
     "never" : "从不",
+    "after" : "之后",
     "At time of event" : "在事件发生的",
     "5 minutes before" : "5分钟前",
     "10 minutes before" : "10分钟前",
@@ -43,8 +45,10 @@ OC.L10N.register(
     "hours" : "小时",
     "days" : "天",
     "week" : "周",
+    "before" : "之前",
     "start" : "开始",
     "end" : "结束",
+    "Editing reminders of unknown type not supported." : "不支持未知类型的编辑提醒",
     "Week {number} of {year}" : "{year}年的第{number}周",
     "Successfully imported" : "导入成功",
     "Partially imported, 1 failure" : "部分导入成功，1个失败",
@@ -64,15 +68,17 @@ OC.L10N.register(
     "starts" : "开始于",
     "ends" : "结束于",
     "All day Event" : "全天事件",
-    "Location" : "地点",
     "Delete" : "删除",
     "Cancel" : "取消",
     "More ..." : "更多...",
     "Create" : "创建",
     "Update" : "更新",
     "Close" : "关闭",
+    "Location" : "地点",
     "Description" : "描述",
     "Export" : "导出",
+    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "由于上游的bug，日历目前无法提供资产管道功能的支持。",
+    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "资产管道功能被禁用，请联系系统管理员。",
     "Day" : "天",
     "Week" : "星期",
     "Month" : "月",
@@ -80,6 +86,9 @@ OC.L10N.register(
     "Share Calendar" : "共享日历",
     "More" : "更多",
     "Edit" : "编辑",
+    "CalDAV" : "日历DAV",
+    "Share with users or groups" : "共享给其他组或者用户",
+    "can edit" : "可编辑",
     "group" : "群组",
     "New Calendar" : "新建日历",
     "Subscriptions" : "订阅",
@@ -95,8 +104,11 @@ OC.L10N.register(
     "Repeat" : "重复",
     "times every" : "次每",
     "Add" : "增加",
+    "E-Mail address of attendee" : "参加者的邮箱地址",
+    "Please add your email address in the personal settings in order to add attendees." : "请在个人设置中设置您的邮箱地址以便添加为参与者",
     "from" : "从",
     "to" : "到",
+    "This event's repeating rule is not supported yet." : "此事件的重复规则还没有被支持。",
     "Repeat every ..." : "重复",
     "end repeat ..." : "结束重复",
     "Import Calendars" : "导入日历",
