@@ -2,7 +2,7 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "日曆",
-    "Individual" : "獨立",
+    "Individual" : "個人",
     "Group" : "群組",
     "Resource" : "資源",
     "Room" : "房間",
@@ -10,6 +10,7 @@ OC.L10N.register(
     "Required" : "必填",
     "Optional" : "選填",
     "Does not attend" : "不參加",
+    "You are in an unknown timezone ({tz}), falling back to UTC" : "未知的時區設定({tz})，返回標準時區(UTC)",
     "Please create a calendar first." : "請先建立一個日曆。",
     "New event" : "新活動",
     "Attendees" : "出席者",
@@ -46,7 +47,6 @@ OC.L10N.register(
     "before" : "前",
     "start" : "開始",
     "end" : "結束",
-    "Editing reminders of uknown type not supported." : "不支援編輯未知類型的提醒",
     "Week {number} of {year}" : "{year} 的第 {number} 週",
     "Successfully imported" : "成功匯入",
     "Partially imported, 1 failure" : "部分匯入，1 個失敗",
@@ -66,15 +66,17 @@ OC.L10N.register(
     "starts" : "開始",
     "ends" : "結束",
     "All day Event" : "全天活動",
-    "Location" : "地點",
     "Delete" : "刪除",
     "Cancel" : "取消",
     "More ..." : "更多…",
     "Create" : "建立",
     "Update" : "更新",
     "Close" : " 關閉",
+    "Location" : "地點",
     "Description" : "描述",
     "Export" : "匯出",
+    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "上傳錯誤，目前不支援asset pipeline功能。",
+    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "請聯絡系統管理員，於設定檔中關閉\"asset-pipeline.enabled\" 選項。",
     "Day" : "日",
     "Week" : "週",
     "Month" : "月",
@@ -82,6 +84,8 @@ OC.L10N.register(
     "Share Calendar" : "分享日曆",
     "More" : "更多",
     "Edit" : "編輯",
+    "Share with users or groups" : "與使用者和群組分享",
+    "can edit" : "可編輯",
     "group" : "群組",
     "New Calendar" : "新日曆",
     "Subscriptions" : "訂閱",
