@@ -31,6 +31,7 @@
 	  ng-show="item.displaySpinner()">
 </span>
 <a class="action permanent"
+   ng-class="{'calendar-list-cut-name': item.calendar.isShared()}"
    href="#"
    ng-click="triggerEnable(item)"
    ng-show="!item.isEditing()"
@@ -55,8 +56,8 @@
 		</span>
 		<!-- Add a label if the calendar has shares -->
 		<span
+			class="calendarlist-icon shared"
 			ng-if="item.calendar.isShared() && item.calendar.isShareable()"
-			style="position: relative; bottom: 16px; left: -12px; width: 30px; opacity: 1"
 			ng-click="item.toggleEditingShares()">
 				<?php p($l->t('Shared'))?>
 		</span>
@@ -74,27 +75,31 @@
 	 class="app-navigation-entry-menu hidden">
 	<ul>
 		<li ng-show="item.calendar.arePropertiesWritable()">
-			<button class="icon-rename svg"
-					ng-click="item.openEditor()"
+			<button	ng-click="item.openEditor()"
 					title="<?php p($l->t('Edit')); ?>">
+				<span class="icon-rename svg"></span>
+				<span><?php p($l->t('Edit')); ?></span>
 			</button>
 		</li>
 		<li>
-			<button class="icon-public svg"
-					ng-click="item.showCalDAVUrl()"
+			<button	ng-click="item.showCalDAVUrl()"
 					title="<?php p($l->t('CalDAV')); ?>">
+				<span class="icon-public svg"></span>
+				<span><?php p($l->t('CalDAV-Link')); ?></span>
 			</button>
 		</li>
 		<li>
-			<button class="icon-download svg"
-					ng-click="download(item)"
+			<button	ng-click="download(item)"
 					title="<?php p($l->t('Export')); ?>">
+				<span class="icon-download svg"></span>
+				<span><?php p($l->t('Export')); ?></span>
 			</button>
 		</li>
 		<li>
-			<button class="icon-delete svg"
-					ng-click="remove(item)"
+			<button	ng-click="remove(item)"
 					title="<?php p($l->t('Delete')); ?>">
+				<span class="icon-delete svg"></span>
+				<span><?php p($l->t('Delete')); ?></span>
 			</button>
 		</li>
 	</ul>
@@ -112,7 +117,7 @@
 		<div class="buttongroups">
 			<button class="primary icon-checkmark-white accept-button">
 			</button>
-			<button class="btn close-button icon-close"
+			<button type="button" class="btn close-button icon-close"
 					ng-click="item.cancelEditor()">
 			</button>
 		</div>
