@@ -24,7 +24,7 @@
 ?>
 <ul class="app-navigation-list subscription-list">
 	<!--<div ng-class="{'icon-loading-small': is.loading}"></div>-->
-	<li ng-repeat="calendar in calendars | orderBy:['order'] | subscriptionFilter" class="app-navigation-list-item" ng-class="{active: calendar.enabled}">
+	<li ng-repeat="item in calendarListItems | orderBy: item.calendar.order | subscriptionListFilter" class="app-navigation-list-item" ng-class="{active: item.calendar.enabled}">
 		<?php print_unescaped($this->inc('part.calendarlist.item')); ?>
 	</li>
 </ul>
